@@ -4,9 +4,10 @@ from typing import Optional, Union
 from doc_printer import DocRenderer, SimpleDocRenderer, SimpleLayout, SmartDocRenderer
 from tree_sitter_talon import Node, parse
 
+from .editorconfig import get_indent_size, get_max_line_length
 from .formatter import EmptyMatchContext, TalonFormatter
 
-__version__: str = "1.8.1"
+__version__: str = "1.9.1"
 
 
 def talonfmt(
@@ -15,7 +16,7 @@ def talonfmt(
     filename: Optional[str] = None,
     encoding: str = "utf-8",
     safe: Optional[bool] = None,
-    indent_size: int = 4,
+    indent_size: Optional[int] = None,
     max_line_width: Optional[int] = None,
     align_match_context: bool = False,
     align_match_context_at: Optional[int] = None,
@@ -26,6 +27,18 @@ def talonfmt(
     empty_match_context: str = "keep",
     preserve_blank_lines: tuple[str, ...] = ("body", "command"),
 ):
+    # Get max_line_width from .editorconfig
+    if filename is not None and max_line_width is None:
+        max_line_width = get_max_line_length(filename)
+
+    # Get indent_size from .editorconfig
+    if filename is not None and indent_size is None:
+        indent_size = get_indent_size(filename)
+
+    # Set default indent_size
+    if indent_size is None:
+        indent_size = 4
+
     # Parse (if necessary):
     if isinstance(contents, Node):
         ast = contents
@@ -112,7 +125,6 @@ def talonfmt(
 
     # safety tests:
     if safe or (safe is None and __debug__):
-
         ast_for_formatted = parse(formatted, encoding=encoding, raise_parse_error=True)
         # assert: parsing output results in a similar AST
         ast.assert_equivalent(ast_for_formatted)
